summaryrefslogtreecommitdiff
path: root/src/xfaces.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/xfaces.c')
-rw-r--r--src/xfaces.c14
1 files changed, 9 insertions, 5 deletions
diff --git a/src/xfaces.c b/src/xfaces.c
index 1b9a9c079f1..398b56f42b6 100644
--- a/src/xfaces.c
+++ b/src/xfaces.c
@@ -1174,14 +1174,11 @@ load_pixmap (f, name, w_ptr, h_ptr)
unsigned int *w_ptr, *h_ptr;
{
int bitmap_id;
- Lisp_Object tem;
if (NILP (name))
return 0;
- tem = Fbitmap_spec_p (name);
- if (NILP (tem))
- wrong_type_argument (Qbitmap_spec_p, name);
+ CHECK_TYPE (!NILP (Fbitmap_spec_p (name)), Qbitmap_spec_p, name);
BLOCK_INPUT;
if (CONSP (name))
@@ -4816,7 +4813,14 @@ x_update_menu_appearance (f)
DEFUN ("face-attribute-relative-p", Fface_attribute_relative_p,
Sface_attribute_relative_p,
2, 2, 0,
- doc: /* Return non-nil if face ATTRIBUTE VALUE is relative. */)
+ doc: /* Check whether a face attribute value is relative.
+Specifically, this function returns t if the attribute ATTRIBUTE
+with the value VALUE is relative.
+
+A relative value is one that doesn't entirely override whatever is
+inherited from another face. For most possible attributes,
+the only relative value that users see is `unspecified'.
+However, for :height, floating point values are also relative. */)
(attribute, value)
Lisp_Object attribute, value;
{